@@ -1,4 +1,3 @@
-
 # fmt: off
 from __future__ import annotations
 
@@ -249,6 +248,13 @@ class Schema(object):
             )
         )
 
+        # Complex required keys that need special validation
+        complex_required_keys = set(
+            key
+            for key in all_required_keys
+            if isinstance(key, Required) and key.is_complex_key
+        )
+
         # Keys that may have defaults
         all_default_keys = set(
             key
@@ -301,6 +307,22 @@ class Schema(object):
                     key_value_map[key.schema] = key.default()
 
             errors = []
+
+            # Check complex required keys - at least one candidate key must be present
+            for complex_key in complex_required_keys:
+                if not any(
+                    candidate in key_value_map
+                    for candidate in complex_key.candidate_keys
+                ):
+                    msg = (
+                        complex_key.msg
+                        if hasattr(complex_key, 'msg') and complex_key.msg
+                        else f'at least one of {complex_key.candidate_keys} is required'
+                    )
+                    errors.append(er.RequiredFieldInvalid(msg, path + [complex_key]))
+                else:
+                    # If at least one candidate key is present, mark this complex requirement as satisfied
+                    required_keys.discard(complex_key)
             for key, value in key_value_map.items():
                 key_path = path + [key]
                 remove_key = False
@@ -363,13 +385,15 @@ class Schema(object):
                     if remove_key:
                         # remove key
                         continue
-                    elif error:
-                        errors.append(error)
                     elif self.extra == ALLOW_EXTRA:
                         out[key] = value
-                    elif self.extra != REMOVE_EXTRA:
+                    elif self.extra == REMOVE_EXTRA:
+                        #  ignore the key so it's removed from output
+                        continue
+                    elif error:
+                        errors.append(error)
+                    else:
                         errors.append(er.Invalid('extra keys not allowed', key_path))
-                        # else REMOVE_EXTRA: ignore the key so it's removed from output
 
             # for any required keys left that weren't found and don't have defaults:
             for key in required_keys:
@@ -1141,6 +1165,17 @@ class Required(Marker):
     >>> schema = Schema({Required('key', default=list): list})
     >>> schema({})
     {'key': []}
+
+    Complex key validation - at least one of the specified keys must be present:
+
+    >>> from voluptuous.validators import Any
+    >>> schema = Schema({Required(Any('color', 'temperature', 'brightness')): str})
+    >>> schema({'color': 'red'})  # Valid - has color
+    {'color': 'red'}
+    >>> schema({'temperature': 'warm'})  # Valid - has temperature
+    {'temperature': 'warm'}
+    >>> schema({'color': 'blue', 'brightness': 'high'})  # Valid - has multiple
+    {'color': 'blue', 'brightness': 'high'}
     """
 
     def __init__(
@@ -1152,6 +1187,31 @@ class Required(Marker):
     ) -> None:
         super(Required, self).__init__(schema, msg=msg, description=description)
         self.default = default_factory(default)
+        self.is_complex_key = self._is_complex_key_validator(schema)
+        self.candidate_keys = (
+            self._extract_candidate_keys(schema) if self.is_complex_key else None
+        )
+
+    def _is_complex_key_validator(self, schema):
+        """Check if schema is a validator that can match multiple keys."""
+        # Import here to avoid circular imports
+        from voluptuous.validators import Any
+
+        return isinstance(schema, Any)
+
+    def _extract_candidate_keys(self, schema):
+        """Extract possible keys from validators like Any("key1", "key2", "key3")."""
+        # Import here to avoid circular imports
+        from voluptuous.validators import Any
+
+        if isinstance(schema, Any):
+            # Extract literal values (strings, ints, etc.) from Any validators
+            return [
+                v
+                for v in schema.validators
+                if isinstance(v, (str, int, float, bool, type(None)))
+            ]
+        return []
 
 
 class Remove(Marker):
